@@ -19,12 +19,6 @@ import time
 from urllib.parse import urlparse
 
 import sushy
-from sushy.resources import base
-from sushy.resources import common
-from sushy.resources.oem import base as oem_base
-from sushy.taskmonitor import TaskMonitor
-from sushy import utils as sushy_utils
-
 from sushy.oem.dell import asynchronous
 from sushy.oem.dell import constants
 from sushy.oem.dell.resources import attributes
@@ -34,6 +28,11 @@ from sushy.oem.dell.resources.manager import job_collection
 from sushy.oem.dell.resources.manager import job_service
 from sushy.oem.dell.resources.manager import lifecycle_service
 from sushy.oem.dell import utils
+from sushy.resources import base
+from sushy.resources import common
+from sushy.resources.oem import base as oem_base
+from sushy.taskmonitor import TaskMonitor
+from sushy import utils as sushy_utils
 
 
 LOG = logging.getLogger(__name__)
@@ -83,7 +82,7 @@ class DellManagerExtension(oem_base.OEMResourceBase):
 
     ACTION_DATA = {
         'ShareParameters': {
-            'Target': 'ALL'
+            'Target': ['ALL']
         },
         'ImportBuffer': None
     }
@@ -395,7 +394,7 @@ VFDD\
 
         action_data = {
             'ShareParameters': {
-                'Target': target
+                'Target': [target]
             },
             'ExportFormat': "JSON",
             'ExportUse': export_use,
