@@ -32,6 +32,7 @@ from sushy.resources import settings
 from sushy.resources.system import bios
 from sushy.resources.system import constants as sys_cons
 from sushy.resources.system import ethernet_interface
+from sushy.resources.system import pcie_device
 from sushy.resources.system import processor
 from sushy.resources.system import secure_boot
 from sushy.resources.system import simple_storage as sys_simple_storage
@@ -61,6 +62,95 @@ class BootField(base.CompositeField):
 
     http_boot_uri = base.Field('HttpBootUri')
 
+    def _load(self, body, resource, nested_in=None):
+        """Load the boot field, checking Settings fallback for missing values.
+
+        Some newer BMCs move some boot values to a nested Settings field
+        which is defined by an attribute on the response body. So we need
+        to check there if any boot field values are None in the main
+        resource.
+        """
+        # Load the field normally first
+        instance = super()._load(body, resource, nested_in)
+
+        if instance is None:
+            return None
+
+        # Check if we have Settings available and any values might be missing
+        if (hasattr(resource, '_settings')
+                and resource._settings
+                and resource._settings.resource_uri):
+
+            try:
+                settings_resp = resource._conn.get(
+                    resource._settings.resource_uri)
+                settings_data = settings_resp.json()
+                settings_boot = settings_data.get('Boot', {})
+
+                if not settings_boot:
+                    return instance
+
+                # Check and populate allowed_values if missing
+                allowable_key = ('BootSourceOverrideTarget@'
+                                 'Redfish.AllowableValues')
+                if (instance.allowed_values is None
+                        and allowable_key in settings_boot):
+                    settings_allowed_values = settings_boot[allowable_key]
+                    if settings_allowed_values:
+                        instance.allowed_values = list(settings_allowed_values)
+
+                # Check and populate enabled if missing/None
+                if (instance.enabled is None
+                        and 'BootSourceOverrideEnabled' in settings_boot):
+                    enabled_value = settings_boot['BootSourceOverrideEnabled']
+                    if enabled_value:
+                        try:
+                            instance.enabled = (
+                                sys_cons.BootSourceOverrideEnabled(
+                                    enabled_value))
+                        except ValueError:
+                            pass  # Keep as None if value is not valid
+
+                # Check and populate mode if missing/None
+                if (instance.mode is None
+                        and 'BootSourceOverrideMode' in settings_boot):
+                    mode_value = settings_boot['BootSourceOverrideMode']
+                    if mode_value:
+                        try:
+                            instance.mode = sys_cons.BootSourceOverrideMode(
+                                mode_value)
+                        except ValueError:
+                            pass  # Keep as None if value is not valid
+
+                # Check and populate target if missing/None
+                if (instance.target is None
+                        and 'BootSourceOverrideTarget' in settings_boot):
+                    target_value = settings_boot['BootSourceOverrideTarget']
+                    if target_value:
+                        try:
+                            instance.target = sys_cons.BootSource(target_value)
+                        except ValueError:
+                            pass  # Keep as None if value is not valid
+
+                # Check and populate http_boot_uri if missing/None
+                if (instance.http_boot_uri is None
+                        and 'HttpBootUri' in settings_boot):
+                    instance.http_boot_uri = settings_boot['HttpBootUri']
+
+                if any([instance.allowed_values, instance.enabled,
+                        instance.mode, instance.target,
+                        instance.http_boot_uri]):
+                    LOG.debug('Retrieved boot field values from Settings '
+                              'resource for System %s',
+                              getattr(resource, 'identity', 'unknown'))
+
+            except Exception as exc:
+                LOG.warning('Failed to retrieve boot field values from '
+                            'Settings resource for System %s: %s',
+                            getattr(resource, 'identity', 'unknown'), exc)
+
+        return instance
+
 
 class BootProgressField(base.CompositeField):
 
@@ -120,6 +210,9 @@ class System(base.ResourceBase):
     manufacturer = base.Field('Manufacturer')
     """The system manufacturer"""
 
+    model = base.Field('Model')
+    """The system model"""
+
     name = base.Field('Name')
     """The system name"""
 
@@ -157,6 +250,7 @@ class System(base.ResourceBase):
     of a Resource
     Ref: http://redfish.dmtf.org/schemas/DSP0266_1.7.0.html#settings-resource
     """
+    _supermicro_models_cd_vmedia = frozenset(['ars-111gl-nhr'])
 
     _actions = ActionsField('Actions', required=True)
 
@@ -175,7 +269,7 @@ class System(base.ResourceBase):
             that needs registries to parse messages.
         :param root: Sushy root object. Empty for Sushy root itself.
         """
-        super(System, self).__init__(
+        super().__init__(
             connector, identity,
             redfish_version=redfish_version,
             registries=registries,
@@ -281,14 +375,20 @@ class System(base.ResourceBase):
 
             target = sys_cons.BootSource(target)
             # NOTE(janders) on SuperMicro X11 and X12 machines, virtual media
-            # is presented as an "USB CD" drive as opposed to a CD drive. Both
+            # is presented as an "USB CD" drive as opposed to a CD drive.
+            # On Supermicro ARS-111GL-NHR however, a more common "CD" device
+            # is used. On both "families" of hardware, both "USB CD" and "CD"
             # are present in the list of boot devices, however only selecting
-            # UsbCd as the boot source results in a successful boot from
-            # vMedia. If "CD" is selected, boot fails even if vMedia is
+            # the appropriate one for the platform as the boot source results
+            # in a successful boot from vMedia. Unless the appropriate option
+            # for a given model is selected, boot fails even if vMedia is
             # inserted. This code detects a case where a SuperMicro machine is
             # about to attempt boot from CD and overrides the boot device to
-            # UsbCd instead which makes boot from vMedia work as expected.
+            # UsbCd if required, depending on the model. This makes boot from
+            # vMedia work as expected on both variants.
             if (self.manufacturer and self.manufacturer.lower() == 'supermicro'
+                    and self.model.lower() not in
+                    self._supermicro_models_cd_vmedia
                     and target == sys_cons.BootSource.CD
                     and sys_cons.BootSource.USB_CD.value
                     in self.boot.allowed_values):
@@ -575,6 +675,32 @@ class System(base.ResourceBase):
             redfish_version=self.redfish_version, registries=self.registries,
             root=self.root)
 
+    @property
+    @utils.cache_it
+    def pcie_devices(self):
+        """Property to reference PCIeDeviceCollection instance"""
+        try:
+            pcie_path = utils.get_sub_resource_path_by(self, "PCIeDevices")
+            return pcie_device.PCIeDeviceCollection(
+                self._conn, pcie_path,
+                redfish_version=self.redfish_version,
+                registries=self.registries, root=self.root)
+        except exceptions.MissingAttributeError:
+            # Check if PCIeDevices is embedded in System JSON
+            if (hasattr(self, 'json') and self.json
+                    and 'PCIeDevices' in self.json):
+                pcie_devices_data = self.json['PCIeDevices']
+                if isinstance(pcie_devices_data, list) and pcie_devices_data:
+                    return pcie_device.PCIeDeviceCollection(
+                        self._conn, "/embedded",
+                        redfish_version=self.redfish_version,
+                        registries=self.registries, root=self.root,
+                        embedded_data=pcie_devices_data)
+            return pcie_device.PCIeDeviceCollection(
+                self._conn, "/empty",
+                redfish_version=self.redfish_version,
+                registries=self.registries, root=self.root)
+
 
 class SystemCollection(base.ResourceCollectionBase):
 
@@ -594,6 +720,6 @@ class SystemCollection(base.ResourceCollectionBase):
             used in any resource that needs registries to parse messages
         :param root: Sushy root object. Empty for Sushy root itself.
         """
-        super(SystemCollection, self).__init__(
+        super().__init__(
             connector, path, redfish_version=redfish_version,
             registries=registries, root=root)
